@@ -3,17 +3,15 @@
 
 #include <curses.h>
 
-#include "tui.h"
-
-struct pipemixer_config_bind {
-    wint_t key; /* ncurses keycode, see curs_getch(3x) */
-    struct tui_bind value;
-};
+#include "collections/hashmap.h"
 
 struct pipemixer_config {
     float volume_step;
     float volume_min, volume_max;
 
+    bool wraparound;
+    bool display_ids;
+
     wchar_t bar_full_char[2], bar_empty_char[2];
     struct {
         wchar_t tl[2], tr[2], bl[2], br[2], cl[2], cr[2], ml[2], mr[2], f[2];
@@ -22,8 +20,9 @@ struct pipemixer_config {
         /* see curs_border(3x) */
         wchar_t ls[2], rs[2], ts[2], bs[2], tl[2], tr[2], bl[2], br[2];
     } borders;
+    char *ports_separator;
 
-    struct pipemixer_config_bind *binds; /* stb_ds hashmap */
+    HASHMAP_HEAD(64) binds;
 };
 
 extern struct pipemixer_config config;
