@@ -16,9 +16,23 @@
     ((byte) & (1 << 1) ? '1' : '0'), \
     ((byte) & (1 << 0) ? '1' : '0')
 
-#define ARRAY_SIZE(arr) (sizeof(arr) / sizeof(arr[0]))
+#define MAX(a, b) (((a) > (b)) ? (a) : (b))
+#define MIN(a, b) (((a) < (b)) ? (a) : (b))
 
-#define WCSEMPTY(str) ((str) == NULL || (str)[0] == L'\0')
+#define TYPEOF(x) __typeof__(x)
+
+#define CONTAINER_OF(member_ptr, container_ptr, member_name) \
+    ((TYPEOF(container_ptr))((char *)(member_ptr) - offsetof(TYPEOF(*container_ptr), member_name)))
+
+#define SIZEOF_ARRAY(arr) (sizeof(arr) / sizeof((arr)[0]))
+
+#define TYPECHECK(type, x) \
+    ({ \
+        type dummy; \
+        TYPEOF(x) dummy2; \
+        (void)(&dummy == &dummy2); \
+        1; \
+    })
 
 #endif /* #ifndef MACROS_H */
 
